View source: R/curve-catmull.R
| plot.ravetools_curve | R Documentation |
ravetools_curvePlots a ravetools_curve object created by
catmull_rom_3d. When the rgl package is available
and use_rgl = TRUE (default), an interactive 3D scene is opened.
Otherwise three 2-D projection panels (x-y, x-z,
y-z) are drawn using base R graphics.
## S3 method for class 'ravetools_curve'
plot(x, n = 200L, col = "steelblue", pch = 19L, cex = 1, use_rgl = TRUE, ...)
x |
an object of class |
n |
integer; number of sample points used to draw the smooth curve.
Default is |
col |
color for the spline curve line. Default |
pch, cex |
plotting character and scaling for the key control points
(base-R fallback only). Default |
use_rgl |
logical; if |
... |
additional graphical parameters forwarded to the underlying plot calls. |
Invisibly returns x.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.