| vcg_average_edge_length | R Documentation |
Computes the average length of all face edges (each edge is counted once
per incident face, so edges shared by two faces are counted twice). Useful
as a scale-aware reference length, e.g. to derive a vertex-merge tolerance
such as the one used internally by vcg_fix_defects.
vcg_average_edge_length(mesh)
mesh |
triangular mesh of class |
A single numeric value: the average edge length, in mesh units.
if (is_not_cran()) {
sphere <- vcg_sphere()
vcg_average_edge_length(sphere)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.